@@ -416,7 +416,7 @@ def indexacion(df,mini,maxi):
     df.insert(df.shape[1],'Index_antiguedad_5',np.select(conditionlist2, choicelist2, default=0))
     df2=df.astype({'antiguedad':'float64','supCSII':'float64','supTSII':'float64','valor':'float64'})
     df3=pd.get_dummies(df2)
-    return choicelist1,choicelist2,df2,df3
+    return df2,df3
   
   # Gráfica de boxplots
 
